==> regina-normal_4.96.orig.tar.gz: regina-4.96/python/surfaces/sfcombination.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Python Interface                                                      *
 *                                                                        *
 *  Copyright (c) 1999-2014, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/* end stub */

#include <boost/python.hpp>
#include "surfaces/sfcombination.h"

using namespace boost::python;
using regina::NSurfaceFilterCombination;

void addNSurfaceFilterCombination() {
    scope s = class_<NSurfaceFilterCombination, bases<regina::NSurfaceFilter>,
            std::auto_ptr<NSurfaceFilterCombination>, boost::noncopyable>
            ("NSurfaceFilterCombination")
        .def(init<const NSurfaceFilterCombination&>())
        .def("getUsesAnd", &NSurfaceFilterCombination::getUsesAnd)
        .def("setUsesAnd", &NSurfaceFilterCombination::setUsesAnd)
    ;

    s.attr("filterID") = regina::SurfaceFilterType(
        NSurfaceFilterCombination::filterID);
    s.attr("filterType") = regina::SurfaceFilterType(
        NSurfaceFilterCombination::filterType);

    implicitly_convertible<std::auto_ptr<NSurfaceFilterCombination>,
        std::auto_ptr<regina::NSurfaceFilter> >();
}

==> regina-normal_5.0.orig.tar.gz: regina-5.0/python/surfaces/sfcombination.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Python Interface                                                      *
 *                                                                        *
 *  Copyright (c) 1999-2016, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

#include "surfaces/sfcombination.h"
#include "../safeheldtype.h"

// Held type must be declared before boost/python.hpp
#include <boost/python.hpp>

using namespace boost::python;
using namespace regina::python;
using regina::NSurfaceFilterCombination;

void addNSurfaceFilterCombination() {
    scope s = class_<NSurfaceFilterCombination, bases<regina::NSurfaceFilter>,
            SafeHeldType<NSurfaceFilterCombination>, boost::noncopyable>
            ("NSurfaceFilterCombination")
        .def(init<const NSurfaceFilterCombination&>())
        .def("usesAnd", &NSurfaceFilterCombination::usesAnd)
        .def("getUsesAnd", &NSurfaceFilterCombination::usesAnd)
        .def("setUsesAnd", &NSurfaceFilterCombination::setUsesAnd)
    ;

    s.attr("filterTypeID") = regina::NS_FILTER_COMBINATION;

    implicitly_convertible<SafeHeldType<NSurfaceFilterCombination>,
        SafeHeldType<regina::NSurfaceFilter> >();
}
